@@ -1,7 +1,7 @@
-use ethers::core::types::{H160, H256, I256, U128, U256};
 use ethers_contract::{abigen, EthAbiType, EthEvent, EthLogDecode};
 use ethers_core::abi::{RawLog, Tokenizable};
 use ethers_core::types::Address;
+use ethers_core::types::{H160, H256, I256, U128, U256};
 
 #[derive(Debug, Clone, PartialEq, EthAbiType)]
 struct ValueChanged {
